pub enum MessageWriteError {
BufferTooSmall,
DupFdFailed(Error),
}Expand description
Error generated when trying to serialize a message into buffers
Variants
BufferTooSmall
The buffer is too small to hold the message contents
DupFdFailed(Error)
The message contains a FD that could not be dup-ed